@@ -1,38 +1,32 @@
 var annotated =
 [
-    [ "bridge_data", "structbridge__data.html", "structbridge__data" ],
     [ "classid_map", "structclassid__map.html", "structclassid__map" ],
-    [ "cls_module", "structcls__module.html", "structcls__module" ],
-    [ "ematch_module", "structematch__module.html", "structematch__module" ],
+    [ "dumb", "structdumb.html", "structdumb" ],
     [ "genl_cmd", "structgenl__cmd.html", "structgenl__cmd" ],
     [ "genl_info", "structgenl__info.html", "structgenl__info" ],
     [ "genl_ops", "structgenl__ops.html", "structgenl__ops" ],
     [ "inet6_data", "structinet6__data.html", "structinet6__data" ],
+    [ "ip6_tnl_info", "structip6__tnl__info.html", "structip6__tnl__info" ],
+    [ "ipgre_info", "structipgre__info.html", "structipgre__info" ],
+    [ "ipip_info", "structipip__info.html", "structipip__info" ],
+    [ "ipvti_info", "structipvti__info.html", "structipvti__info" ],
     [ "meta_data", "structmeta__data.html", "structmeta__data" ],
     [ "nbyte_data", "structnbyte__data.html", "structnbyte__data" ],
-    [ "nl_af_group", "structnl__af__group.html", "structnl__af__group" ],
-    [ "nl_cache_ops", "structnl__cache__ops.html", "structnl__cache__ops" ],
+    [ "nfnl_ct_timestamp", "structnfnl__ct__timestamp.html", "structnfnl__ct__timestamp" ],
     [ "nl_cli_tc_module", "structnl__cli__tc__module.html", "structnl__cli__tc__module" ],
     [ "nl_derived_object", "structnl__derived__object.html", "structnl__derived__object" ],
     [ "nl_dump_params", "structnl__dump__params.html", "structnl__dump__params" ],
     [ "nl_hash_node", "structnl__hash__node.html", "structnl__hash__node" ],
     [ "nl_hash_table", "structnl__hash__table.html", "structnl__hash__table" ],
     [ "nl_list_head", "structnl__list__head.html", "structnl__list__head" ],
-    [ "nl_msgtype", "structnl__msgtype.html", "structnl__msgtype" ],
-    [ "nl_object", "structnl__object.html", null ],
-    [ "nl_object_ops", "structnl__object__ops.html", "structnl__object__ops" ],
-    [ "nl_parser_param", "structnl__parser__param.html", "structnl__parser__param" ],
     [ "nla_policy", "structnla__policy.html", "structnla__policy" ],
     [ "rtnl_basic", "structrtnl__basic.html", "structrtnl__basic" ],
     [ "rtnl_ematch_ops", "structrtnl__ematch__ops.html", "structrtnl__ematch__ops" ],
     [ "rtnl_link", "structrtnl__link.html", null ],
-    [ "rtnl_link_af_ops", "structrtnl__link__af__ops.html", "structrtnl__link__af__ops" ],
-    [ "rtnl_link_info_ops", "structrtnl__link__info__ops.html", "structrtnl__link__info__ops" ],
     [ "rtnl_meta_value", "structrtnl__meta__value.html", "structrtnl__meta__value" ],
     [ "rtnl_pktloc", "structrtnl__pktloc.html", "structrtnl__pktloc" ],
     [ "rtnl_rtcacheinfo", "structrtnl__rtcacheinfo.html", "structrtnl__rtcacheinfo" ],
-    [ "rtnl_tc_ops", "structrtnl__tc__ops.html", "structrtnl__tc__ops" ],
-    [ "rtnl_tc_type_ops", "structrtnl__tc__type__ops.html", "structrtnl__tc__type__ops" ],
+    [ "sit_info", "structsit__info.html", "structsit__info" ],
     [ "text_data", "structtext__data.html", "structtext__data" ],
     [ "vlan_map", "structvlan__map.html", "structvlan__map" ],
     [ "yy_buffer_state", "structyy__buffer__state.html", "structyy__buffer__state" ],
