@@ -1,7 +1,8 @@
 var group__object =
 [
-    [ "Object API", "group__object__api.html", "group__object__api" ],
-    [ "nl_derived_object", "structnl__derived__object.html", null ],
+    [ "nl_derived_object", "structnl__derived__object.html", [
+      [ "data", "structnl__derived__object.html#af34d568582157be096cdb92445ef1afc", null ]
+    ] ],
     [ "nl_object_alloc", "group__object.html#ga9c1f2fd887d8325839f452879cdf982a", null ],
     [ "nl_object_alloc_name", "group__object.html#ga0096c8024ff3e79fc1968eb44cecd3bc", null ],
     [ "nl_object_clone", "group__object.html#ga90d86d45c53d2be6ba927bec662159d7", null ],
@@ -24,5 +25,6 @@ var group__object =
     [ "nl_object_get_cache", "group__object.html#gad2aa1ab8d0b7996714af1eccc7842667", null ],
     [ "nl_object_get_type", "group__object.html#gad5ce0b233310c3358cda2876ebc86b50", null ],
     [ "nl_object_get_msgtype", "group__object.html#ga5c483621e839bb4d5a23e77623841364", null ],
-    [ "nl_object_get_ops", "group__object.html#ga1aad866c11d0df63050843da0e25c320", null ]
+    [ "nl_object_get_ops", "group__object.html#ga1aad866c11d0df63050843da0e25c320", null ],
+    [ "nl_object_get_id_attrs", "group__object.html#ga767edde88f01f7ad9f303397a6304000", null ]
 ];
\ No newline at end of file
