@@ -1,39 +1,34 @@
 var hierarchy =
 [
-    [ "bridge_data", "structbridge__data.html", null ],
     [ "classid_map", "structclassid__map.html", null ],
-    [ "cls_module", "structcls__module.html", null ],
-    [ "ematch_module", "structematch__module.html", null ],
+    [ "dumb", "structdumb.html", null ],
     [ "genl_cmd", "structgenl__cmd.html", null ],
     [ "genl_info", "structgenl__info.html", null ],
     [ "genl_ops", "structgenl__ops.html", null ],
     [ "inet6_data", "structinet6__data.html", null ],
+    [ "ip6_tnl_info", "structip6__tnl__info.html", null ],
+    [ "ipgre_info", "structipgre__info.html", null ],
+    [ "ipip_info", "structipip__info.html", null ],
+    [ "ipvti_info", "structipvti__info.html", null ],
     [ "meta_data", "structmeta__data.html", null ],
     [ "nbyte_data", "structnbyte__data.html", null ],
-    [ "nl_af_group", "structnl__af__group.html", null ],
-    [ "nl_cache_ops", "structnl__cache__ops.html", null ],
+    [ "nfnl_ct_timestamp", "structnfnl__ct__timestamp.html", null ],
     [ "nl_cli_tc_module", "structnl__cli__tc__module.html", null ],
     [ "nl_derived_object", "structnl__derived__object.html", null ],
     [ "nl_dump_params", "structnl__dump__params.html", null ],
     [ "nl_hash_node", "structnl__hash__node.html", null ],
     [ "nl_hash_table", "structnl__hash__table.html", null ],
     [ "nl_list_head", "structnl__list__head.html", null ],
-    [ "nl_msgtype", "structnl__msgtype.html", null ],
-    [ "nl_object", "structnl__object.html", [
+    [ "nl_object", null, [
       [ "rtnl_link", "structrtnl__link.html", null ]
     ] ],
-    [ "nl_object_ops", "structnl__object__ops.html", null ],
-    [ "nl_parser_param", "structnl__parser__param.html", null ],
     [ "nla_policy", "structnla__policy.html", null ],
     [ "rtnl_basic", "structrtnl__basic.html", null ],
     [ "rtnl_ematch_ops", "structrtnl__ematch__ops.html", null ],
-    [ "rtnl_link_af_ops", "structrtnl__link__af__ops.html", null ],
-    [ "rtnl_link_info_ops", "structrtnl__link__info__ops.html", null ],
     [ "rtnl_meta_value", "structrtnl__meta__value.html", null ],
     [ "rtnl_pktloc", "structrtnl__pktloc.html", null ],
     [ "rtnl_rtcacheinfo", "structrtnl__rtcacheinfo.html", null ],
-    [ "rtnl_tc_ops", "structrtnl__tc__ops.html", null ],
-    [ "rtnl_tc_type_ops", "structrtnl__tc__type__ops.html", null ],
+    [ "sit_info", "structsit__info.html", null ],
     [ "text_data", "structtext__data.html", null ],
     [ "vlan_map", "structvlan__map.html", null ],
     [ "yy_buffer_state", "structyy__buffer__state.html", null ],
